<?php
session_start(); // Initialize session data
ob_start(); // Turn on output buffering
?>
<?php include "ewcfg6.php" ?>
<?php include "ewmysql6.php" ?>
<?php include "phpfn6.php" ?>
<?php include "linea_productoinfo.php" ?>
<?php include "categoriainfo.php" ?>
<?php include "usuarioinfo.php" ?>
<?php include "userfn6.php" ?>
<?php
header("Expires: Mon, 26 Jul 1997 05:00:00 GMT"); // Date in the past
header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT"); // Always modified
header("Cache-Control: private, no-store, no-cache, must-revalidate"); // HTTP/1.1 
header("Cache-Control: post-check=0, pre-check=0", false);
header("Pragma: no-cache"); // HTTP/1.0
?>
<?php

// Define page object
$linea_producto_delete = new clinea_producto_delete();
$Page =& $linea_producto_delete;

// Page init processing
$linea_producto_delete->Page_Init();

// Page main processing
$linea_producto_delete->Page_Main();
?>
<?php include "header.php" ?>
<script type="text/javascript">
<!--

// Create page object
var linea_producto_delete = new ew_Page("linea_producto_delete");

// page properties
linea_producto_delete.PageID = "delete"; // page ID
var EW_PAGE_ID = linea_producto_delete.PageID; // for backward compatibility

// extend page with Form_CustomValidate function
linea_producto_delete.Form_CustomValidate = 
 function(fobj) { // DO NOT CHANGE THIS LINE!

 	// Your custom validation code here, return false if invalid. 
 	return true;
 }
<?php if (EW_CLIENT_VALIDATE) { ?>
linea_producto_delete.ValidateRequired = true; // uses JavaScript validation
<?php } else { ?>
linea_producto_delete.ValidateRequired = false; // no JavaScript validation
<?php } ?>

//-->
</script>
<script language="JavaScript" type="text/javascript">
<!--

// Write your client script here, no need to add script tags.
// To include another .js script, use:
// ew_ClientScriptInclude("my_javascript.js"); 
//-->

</script>
<?php

// Load records for display
$rs = $linea_producto_delete->LoadRecordset();
$linea_producto_deletelTotalRecs = $rs->RecordCount(); // Get record count
if ($linea_producto_deletelTotalRecs <= 0) { // No record found, exit
	$rs->Close();
	$linea_producto_delete->Page_Terminate("linea_productolist.php"); // Return to list
}
?>
<p><span class="phpmaker">Borrar de TABLA: lineas<br><br>
<a href="<?php echo $linea_producto->getReturnUrl() ?>">Regresar</a></span></p>
<?php $linea_producto_delete->ShowMessage() ?>
<form action="<?php echo ew_CurrentPage() ?>" method="post">
<p>
<input type="hidden" name="t" id="t" value="linea_producto">
<input type="hidden" name="a_delete" id="a_delete" value="D">
<?php foreach ($linea_producto_delete->arRecKeys as $key) { ?>
<input type="hidden" name="key_m[]" id="key_m[]" value="<?php echo ew_HtmlEncode($key) ?>">
<?php } ?>
<table class="ewGrid"><tr><td class="ewGridContent">
<div class="ewGridMiddlePanel">
<table cellspacing="0" class="ewTable ewTableSeparate">
<?php echo $linea_producto->TableCustomInnerHtml ?>
	<thead>
	<tr class="ewTableHeader">
		<td valign="top">cod linea</td>
		<td valign="top">descripción</td>
		<td valign="top">activo</td>
		<td valign="top">cat</td>
		<td valign="top">orden</td>
	</tr>
	</thead>
	<tbody>
<?php
$linea_producto_delete->lRecCnt = 0;
$i = 0;
while (!$rs->EOF) {
	$linea_producto_delete->lRecCnt++;

	// Set row properties
	$linea_producto->CssClass = "";
	$linea_producto->CssStyle = "";
	$linea_producto->RowType = EW_ROWTYPE_VIEW; // View

	// Get the field contents
	$linea_producto_delete->LoadRowValues($rs);

	// Render row
	$linea_producto_delete->RenderRow();
?>
	<tr<?php echo $linea_producto->RowAttributes() ?>>
		<td<?php echo $linea_producto->cod_linea_producto->CellAttributes() ?>>
<div<?php echo $linea_producto->cod_linea_producto->ViewAttributes() ?>><?php echo $linea_producto->cod_linea_producto->ListViewValue() ?></div></td>
		<td<?php echo $linea_producto->des_linea_producto->CellAttributes() ?>>
<div<?php echo $linea_producto->des_linea_producto->ViewAttributes() ?>><?php echo $linea_producto->des_linea_producto->ListViewValue() ?></div></td>
		<td<?php echo $linea_producto->ind_activo->CellAttributes() ?>>
<div<?php echo $linea_producto->ind_activo->ViewAttributes() ?>><?php echo $linea_producto->ind_activo->ListViewValue() ?></div></td>
		<td<?php echo $linea_producto->ind_cat->CellAttributes() ?>>
<div<?php echo $linea_producto->ind_cat->ViewAttributes() ?>><?php echo $linea_producto->ind_cat->ListViewValue() ?></div></td>
		<td<?php echo $linea_producto->orden->CellAttributes() ?>>
<div<?php echo $linea_producto->orden->ViewAttributes() ?>><?php echo $linea_producto->orden->ListViewValue() ?></div></td>
	</tr>
<?php
	$rs->MoveNext();
}
$rs->Close();
?>
</tbody>
</table>
</div>
</td></tr></table>
<p>
<input type="submit" name="Action" id="Action" value="Confirmar Borrado">
</form>
<script language="JavaScript" type="text/javascript">
<!--

// Write your table-specific startup script here
// document.write("page loaded");
//-->

</script>
<?php include "footer.php" ?>
<?php

//
// Page Class
//
class clinea_producto_delete {

	// Page ID
	var $PageID = 'delete';

	// Table Name
	var $TableName = 'linea_producto';

	// Page Object Name
	var $PageObjName = 'linea_producto_delete';

	// Page Name
	function PageName() {
		return ew_CurrentPage();
	}

	// Page Url
	function PageUrl() {
		$PageUrl = ew_CurrentPage() . "?";
		global $linea_producto;
		if ($linea_producto->UseTokenInUrl) $PageUrl .= "t=" . $linea_producto->TableVar . "&"; // add page token
		return $PageUrl;
	}

	// Message
	function getMessage() {
		return @$_SESSION[EW_SESSION_MESSAGE];
	}

	function setMessage($v) {
		if (@$_SESSION[EW_SESSION_MESSAGE] <> "") { // Append
			$_SESSION[EW_SESSION_MESSAGE] .= "<br>" . $v;
		} else {
			$_SESSION[EW_SESSION_MESSAGE] = $v;
		}
	}

	// Show Message
	function ShowMessage() {
		if ($this->getMessage() <> "") { // Message in Session, display
			echo "<p><span class=\"ewMessage\">" . $this->getMessage() . "</span></p>";
			$_SESSION[EW_SESSION_MESSAGE] = ""; // Clear message in Session
		}
	}

	// Validate Page request
	function IsPageRequest() {
		global $objForm, $linea_producto;
		if ($linea_producto->UseTokenInUrl) {

			//IsPageRequest = False
			if ($objForm)
				return ($linea_producto->TableVar == $objForm->GetValue("t"));
			if (@$_GET["t"] <> "")
				return ($linea_producto->TableVar == $_GET["t"]);
		} else {
			return TRUE;
		}
	}

	//
	//  Class initialize
	//  - init objects
	//  - open connection
	//
	function clinea_producto_delete() {
		global $conn;

		// Initialize table object
		$GLOBALS["linea_producto"] = new clinea_producto();

		// Initialize other table object
		$GLOBALS['categoria'] = new ccategoria();

		// Initialize other table object
		$GLOBALS['usuario'] = new cusuario();

		// Intialize page id (for backward compatibility)
		if (!defined("EW_PAGE_ID"))
			define("EW_PAGE_ID", 'delete', TRUE);

		// Initialize table name (for backward compatibility)
		if (!defined("EW_TABLE_NAME"))
			define("EW_TABLE_NAME", 'linea_producto', TRUE);

		// Open connection to the database
		$conn = ew_Connect();
	}

	// 
	//  Page_Init
	//
	function Page_Init() {
		global $gsExport, $gsExportFile, $linea_producto;
		global $Security;
		$Security = new cAdvancedSecurity();
		if (!$Security->IsLoggedIn()) $Security->AutoLogin();
		if (!$Security->IsLoggedIn()) {
			$Security->SaveLastUrl();
			$this->Page_Terminate("login.php");
		}

		// Global page loading event (in userfn6.php)
		Page_Loading();

		// Page load event, used in current page
		$this->Page_Load();
	}

	//
	//  Page_Terminate
	//  - called when exit page
	//  - if URL specified, redirect to the URL
	//
	function Page_Terminate($url = "") {
		global $conn;

		// Page unload event, used in current page
		$this->Page_Unload();

		// Global page unloaded event (in userfn*.php)
		Page_Unloaded();

		 // Close Connection
		$conn->Close();

		// Go to URL if specified
		if ($url <> "") {
			ob_end_clean();
			header("Location: $url");
		}
		exit();
	}
	var $lTotalRecs;
	var $lRecCnt;
	var $arRecKeys = array();

	// Page main processing
	function Page_Main() {
		global $linea_producto;

		// Load Key Parameters
		$sKey = "";
		$bSingleDelete = TRUE; // Initialize as single delete
		$nKeySelected = 0; // Initialize selected key count
		$sFilter = "";
		if (@$_GET["cod_linea_producto"] <> "") {
			$linea_producto->cod_linea_producto->setQueryStringValue($_GET["cod_linea_producto"]);
			$sKey .= $linea_producto->cod_linea_producto->QueryStringValue;
		} else {
			$bSingleDelete = FALSE;
		}
		if (@$_GET["cod_categoria"] <> "") {
			$linea_producto->cod_categoria->setQueryStringValue($_GET["cod_categoria"]);
			if ($sKey <> "") $sKey .= EW_COMPOSITE_KEY_SEPARATOR;
			$sKey .= $linea_producto->cod_categoria->QueryStringValue;
		} else {
			$bSingleDelete = FALSE;
		}
		if ($bSingleDelete) {
			$nKeySelected = 1; // Set up key selected count
			$this->arRecKeys[0] = $sKey;
		} else {
			if (isset($_POST["key_m"])) { // Key in form
				$nKeySelected = count($_POST["key_m"]); // Set up key selected count
				$this->arRecKeys = ew_StripSlashes($_POST["key_m"]);
			}
		}
		if ($nKeySelected <= 0)
			$this->Page_Terminate("linea_productolist.php"); // No key specified, return to list

		// Build filter
		foreach ($this->arRecKeys as $sKey) {
			$sFilter .= "(";
			$arKeyFlds = explode(EW_COMPOSITE_KEY_SEPARATOR, trim($sKey)); // Split key by separator
			if (count($arKeyFlds) <> 2)
				$this->Page_Terminate($linea_producto->getReturnUrl()); // Invalid key, exit

			// Set up key field
			$sKeyFld = $arKeyFlds[0];
			$sFilter .= "`cod_linea_producto`='" . ew_AdjustSql($sKeyFld) . "' AND ";

			// Set up key field
			$sKeyFld = $arKeyFlds[1];
			$sFilter .= "`cod_categoria`='" . ew_AdjustSql($sKeyFld) . "' AND ";
			if (substr($sFilter, -5) == " AND ") $sFilter = substr($sFilter, 0, strlen($sFilter)-5) . ") OR ";
		}
		if (substr($sFilter, -4) == " OR ") $sFilter = substr($sFilter, 0, strlen($sFilter)-4);

		// Set up filter (SQL WhHERE clause) and get return SQL
		// SQL constructor in SQL constructor in linea_producto class, linea_productoinfo.php

		$linea_producto->CurrentFilter = $sFilter;

		// Get action
		if (@$_POST["a_delete"] <> "") {
			$linea_producto->CurrentAction = $_POST["a_delete"];
		} else {
			$linea_producto->CurrentAction = "I"; // Display record
		}
		switch ($linea_producto->CurrentAction) {
			case "D": // Delete
				$linea_producto->SendEmail = TRUE; // Send email on delete success
				if ($this->DeleteRows()) { // delete rows
					$this->setMessage("Borrado con exito"); // Set up success message
					$this->Page_Terminate($linea_producto->getReturnUrl()); // Return to caller
				}
		}
	}

	//
	//  Function DeleteRows
	//  - Delete Records based on current filter
	//
	function DeleteRows() {
		global $conn, $Security, $linea_producto;
		$DeleteRows = TRUE;
		$sWrkFilter = $linea_producto->CurrentFilter;

		// Set up filter (Sql Where Clause) and get Return SQL
		// SQL constructor in linea_producto class, linea_productoinfo.php

		$linea_producto->CurrentFilter = $sWrkFilter;
		$sSql = $linea_producto->SQL();
		$conn->raiseErrorFn = 'ew_ErrorFn';
		$rs = $conn->Execute($sSql);
		$conn->raiseErrorFn = '';
		if ($rs === FALSE) {
			return FALSE;
		} elseif ($rs->EOF) {
			$this->setMessage("No se encontraron registros"); // No record found
			$rs->Close();
			return FALSE;
		}
		$conn->BeginTrans();

		// Clone old rows
		$rsold = ($rs) ? $rs->GetRows() : array();
		if ($rs) $rs->Close();

		// Call row deleting event
		if ($DeleteRows) {
			foreach ($rsold as $row) {
				$DeleteRows = $linea_producto->Row_Deleting($row);
				if (!$DeleteRows) break;
			}
		}
		if ($DeleteRows) {
			$sKey = "";
			foreach ($rsold as $row) {
				$sThisKey = "";
				if ($sThisKey <> "") $sThisKey .= EW_COMPOSITE_KEY_SEPARATOR;
				$sThisKey .= $row['cod_linea_producto'];
				if ($sThisKey <> "") $sThisKey .= EW_COMPOSITE_KEY_SEPARATOR;
				$sThisKey .= $row['cod_categoria'];
				$conn->raiseErrorFn = 'ew_ErrorFn';
				$DeleteRows = $conn->Execute($linea_producto->DeleteSQL($row)); // Delete
				$conn->raiseErrorFn = '';
				if ($DeleteRows === FALSE)
					break;
				if ($sKey <> "") $sKey .= ", ";
				$sKey .= $sThisKey;
			}
		} else {

			// Set up error message
			if ($linea_producto->CancelMessage <> "") {
				$this->setMessage($linea_producto->CancelMessage);
				$linea_producto->CancelMessage = "";
			} else {
				$this->setMessage("Borrar cancelado");
			}
		}
		if ($DeleteRows) {
			$conn->CommitTrans(); // Commit the changes
		} else {
			$conn->RollbackTrans(); // Rollback changes
		}

		// Call recordset deleted event
		if ($DeleteRows) {
			foreach ($rsold as $row) {
				$linea_producto->Row_Deleted($row);
			}	
		}
		return $DeleteRows;
	}

	// Load recordset
	function LoadRecordset($offset = -1, $rowcnt = -1) {
		global $conn, $linea_producto;

		// Call Recordset Selecting event
		$linea_producto->Recordset_Selecting($linea_producto->CurrentFilter);

		// Load list page SQL
		$sSql = $linea_producto->SelectSQL();
		if ($offset > -1 && $rowcnt > -1) $sSql .= " LIMIT $offset, $rowcnt";

		// Load recordset
		$conn->raiseErrorFn = 'ew_ErrorFn';	
		$rs = $conn->Execute($sSql);
		$conn->raiseErrorFn = '';

		// Call Recordset Selected event
		$linea_producto->Recordset_Selected($rs);
		return $rs;
	}

	// Load row based on key values
	function LoadRow() {
		global $conn, $Security, $linea_producto;
		$sFilter = $linea_producto->KeyFilter();

		// Call Row Selecting event
		$linea_producto->Row_Selecting($sFilter);

		// Load sql based on filter
		$linea_producto->CurrentFilter = $sFilter;
		$sSql = $linea_producto->SQL();
		if ($rs = $conn->Execute($sSql)) {
			if ($rs->EOF) {
				$LoadRow = FALSE;
			} else {
				$LoadRow = TRUE;
				$rs->MoveFirst();
				$this->LoadRowValues($rs); // Load row values

				// Call Row Selected event
				$linea_producto->Row_Selected($rs);
			}
			$rs->Close();
		} else {
			$LoadRow = FALSE;
		}
		return $LoadRow;
	}

	// Load row values from recordset
	function LoadRowValues(&$rs) {
		global $linea_producto;
		$linea_producto->cod_linea_producto->setDbValue($rs->fields('cod_linea_producto'));
		$linea_producto->cod_categoria->setDbValue($rs->fields('cod_categoria'));
		$linea_producto->des_linea_producto->setDbValue($rs->fields('des_linea_producto'));
		$linea_producto->des_abreviada->setDbValue($rs->fields('des_abreviada'));
		$linea_producto->ind_activo->setDbValue($rs->fields('ind_activo'));
		$linea_producto->ind_cat->setDbValue($rs->fields('ind_cat'));
		$linea_producto->orden->setDbValue($rs->fields('orden'));
		$linea_producto->cod_usuario_registro->setDbValue($rs->fields('cod_usuario_registro'));
		$linea_producto->fec_registro->setDbValue($rs->fields('fec_registro'));
		$linea_producto->cod_usuario_modificacion->setDbValue($rs->fields('cod_usuario_modificacion'));
		$linea_producto->fec_ultima_modificacion->setDbValue($rs->fields('fec_ultima_modificacion'));
	}

	// Render row values based on field settings
	function RenderRow() {
		global $conn, $Security, $linea_producto;

		// Call Row_Rendering event
		$linea_producto->Row_Rendering();

		// Common render codes for all row types
		// cod_linea_producto

		$linea_producto->cod_linea_producto->CellCssStyle = "";
		$linea_producto->cod_linea_producto->CellCssClass = "";

		// des_linea_producto
		$linea_producto->des_linea_producto->CellCssStyle = "";
		$linea_producto->des_linea_producto->CellCssClass = "";

		// ind_activo
		$linea_producto->ind_activo->CellCssStyle = "";
		$linea_producto->ind_activo->CellCssClass = "";

		// ind_cat
		$linea_producto->ind_cat->CellCssStyle = "";
		$linea_producto->ind_cat->CellCssClass = "";

		// orden
		$linea_producto->orden->CellCssStyle = "";
		$linea_producto->orden->CellCssClass = "";
		if ($linea_producto->RowType == EW_ROWTYPE_VIEW) { // View row

			// cod_linea_producto
			$linea_producto->cod_linea_producto->ViewValue = $linea_producto->cod_linea_producto->CurrentValue;
			$linea_producto->cod_linea_producto->CssStyle = "";
			$linea_producto->cod_linea_producto->CssClass = "";
			$linea_producto->cod_linea_producto->ViewCustomAttributes = "";

			// cod_categoria
			$linea_producto->cod_categoria->ViewValue = $linea_producto->cod_categoria->CurrentValue;
			$linea_producto->cod_categoria->CssStyle = "";
			$linea_producto->cod_categoria->CssClass = "";
			$linea_producto->cod_categoria->ViewCustomAttributes = "";

			// des_linea_producto
			$linea_producto->des_linea_producto->ViewValue = $linea_producto->des_linea_producto->CurrentValue;
			$linea_producto->des_linea_producto->CssStyle = "";
			$linea_producto->des_linea_producto->CssClass = "";
			$linea_producto->des_linea_producto->ViewCustomAttributes = "";

			// des_abreviada
			$linea_producto->des_abreviada->ViewValue = $linea_producto->des_abreviada->CurrentValue;
			$linea_producto->des_abreviada->CssStyle = "";
			$linea_producto->des_abreviada->CssClass = "";
			$linea_producto->des_abreviada->ViewCustomAttributes = "";

			// ind_activo
			$linea_producto->ind_activo->ViewValue = $linea_producto->ind_activo->CurrentValue;
			$linea_producto->ind_activo->CssStyle = "";
			$linea_producto->ind_activo->CssClass = "";
			$linea_producto->ind_activo->ViewCustomAttributes = "";

			// ind_cat
			$linea_producto->ind_cat->ViewValue = $linea_producto->ind_cat->CurrentValue;
			$linea_producto->ind_cat->CssStyle = "";
			$linea_producto->ind_cat->CssClass = "";
			$linea_producto->ind_cat->ViewCustomAttributes = "";

			// orden
			$linea_producto->orden->ViewValue = $linea_producto->orden->CurrentValue;
			$linea_producto->orden->CssStyle = "";
			$linea_producto->orden->CssClass = "";
			$linea_producto->orden->ViewCustomAttributes = "";

			// cod_usuario_registro
			$linea_producto->cod_usuario_registro->ViewValue = $linea_producto->cod_usuario_registro->CurrentValue;
			$linea_producto->cod_usuario_registro->CssStyle = "";
			$linea_producto->cod_usuario_registro->CssClass = "";
			$linea_producto->cod_usuario_registro->ViewCustomAttributes = "";

			// fec_registro
			$linea_producto->fec_registro->ViewValue = $linea_producto->fec_registro->CurrentValue;
			$linea_producto->fec_registro->ViewValue = ew_FormatDateTime($linea_producto->fec_registro->ViewValue, 5);
			$linea_producto->fec_registro->CssStyle = "";
			$linea_producto->fec_registro->CssClass = "";
			$linea_producto->fec_registro->ViewCustomAttributes = "";

			// cod_usuario_modificacion
			$linea_producto->cod_usuario_modificacion->ViewValue = $linea_producto->cod_usuario_modificacion->CurrentValue;
			$linea_producto->cod_usuario_modificacion->CssStyle = "";
			$linea_producto->cod_usuario_modificacion->CssClass = "";
			$linea_producto->cod_usuario_modificacion->ViewCustomAttributes = "";

			// fec_ultima_modificacion
			$linea_producto->fec_ultima_modificacion->ViewValue = $linea_producto->fec_ultima_modificacion->CurrentValue;
			$linea_producto->fec_ultima_modificacion->ViewValue = ew_FormatDateTime($linea_producto->fec_ultima_modificacion->ViewValue, 5);
			$linea_producto->fec_ultima_modificacion->CssStyle = "";
			$linea_producto->fec_ultima_modificacion->CssClass = "";
			$linea_producto->fec_ultima_modificacion->ViewCustomAttributes = "";

			// cod_linea_producto
			$linea_producto->cod_linea_producto->HrefValue = "";

			// des_linea_producto
			$linea_producto->des_linea_producto->HrefValue = "";

			// ind_activo
			$linea_producto->ind_activo->HrefValue = "";

			// ind_cat
			$linea_producto->ind_cat->HrefValue = "";

			// orden
			$linea_producto->orden->HrefValue = "";
		}

		// Call Row Rendered event
		$linea_producto->Row_Rendered();
	}

	// Page Load event
	function Page_Load() {

		//echo "Page Load";
	}

	// Page Unload event
	function Page_Unload() {

		//echo "Page Unload";
	}
}
?>
